import { type Network } from "@wormhole-foundation/sdk-base";
import { type AccountAddress, type ChainAddress, type ChainsConfig, Contracts, UnsignedTransaction } from "@wormhole-foundation/sdk-definitions";
import { Ntt, NttWithExecutor } from "@wormhole-foundation/sdk-definitions-ntt";
import { type SolanaPlatformType, type SolanaChains } from "@wormhole-foundation/sdk-solana";
import { Connection, PublicKey } from "@solana/web3.js";
import { SolanaNtt } from "./ntt.js";
export declare class SolanaNttWithExecutor<N extends Network, C extends SolanaChains> implements NttWithExecutor<N, C> {
    readonly network: N;
    readonly chain: C;
    readonly connection: Connection;
    readonly contracts: Contracts & {
        ntt?: Ntt.Contracts;
    };
    readonly nttWithExecutorProgramId: PublicKey;
    readonly nttLutProgramId: PublicKey;
    readonly executorProgramId: PublicKey;
    constructor(network: N, chain: C, connection: Connection, contracts: Contracts & {
        ntt?: Ntt.Contracts;
    });
    static fromRpc<N extends Network>(connection: Connection, config: ChainsConfig<N, SolanaPlatformType>): Promise<SolanaNttWithExecutor<N, SolanaChains>>;
    transfer(sender: AccountAddress<C>, destination: ChainAddress, amount: bigint, quote: NttWithExecutor.Quote, ntt: SolanaNtt<N, C>, wrapNative?: boolean): AsyncGenerator<UnsignedTransaction<N, C>>;
    static associatedTokenAccountMinRent: bigint | undefined;
    estimateMsgValueAndGasLimit(recipient: ChainAddress | undefined): Promise<{
        msgValue: bigint;
        gasLimit: bigint;
    }>;
}
//# sourceMappingURL=nttWithExecutor.d.ts.map